@@ -3,7 +3,7 @@
 
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
-from copy import copy
+from copy import copy, deepcopy
 from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 from mitosheet.code_chunks.code_chunk import CodeChunk
@@ -46,11 +46,12 @@ class DataframeDuplicateStepPerformer(StepPerformer):
         # than the column_ids created initially (e.g. because of renames), we have to go through and updated
         # the mapping with the new column ids that the format types must rely on
         old_df_format = post_state.df_formats[sheet_index]
-        new_df_format = post_state.df_formats[sheet_index].copy()
-        for column_id, column_header in post_state.column_ids.get_column_ids_map(sheet_index).items():
+        new_df_format = deepcopy(post_state.df_formats[sheet_index])
+        for old_column_id, column_header in post_state.column_ids.get_column_ids_map(sheet_index).items():
             new_column_id = get_column_header_id(column_header)
-            old_column_format = old_df_format['columns'].get(column_id, None)
+            old_column_format = old_df_format['columns'].get(old_column_id, None)
             if old_column_format is not None:
+                del new_df_format['columns'][old_column_id]
                 new_df_format['columns'][new_column_id] = old_column_format
 
         post_state.add_df_to_state(df_copy, DATAFRAME_SOURCE_DUPLICATED, df_name=new_name, df_format=new_df_format)
