@@ -594,6 +594,36 @@ class MitoWidgetTestWrapper:
             }
         )
     
+
+    @check_transpiled_code_after_call
+    def ai_transformation(
+            self, 
+            user_input: str,
+            prompt_version: str,
+            prompt: str,
+            completion: str,
+            edited_completion: str,
+        ) -> bool:
+
+        
+
+        return self.mito_backend.receive_message(
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'ai_transformation_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'user_input': user_input,
+                    'prompt_version': prompt_version,
+                    'prompt': prompt,
+                    'completion': completion,
+                    'edited_completion': edited_completion,
+                    
+                }
+            }
+        )
+    
 # AUTOGENERATED LINE: TEST (DO NOT DELETE)
 
     @check_transpiled_code_after_call
